@@ -807,6 +807,19 @@ typedef
 #define vki_kevent kevent
 #define vki_kevent64 kevent64_s
 
+// xnu_root/bsd/sys/event.h
+
+struct vki_kevent_qos_s {
+    uint64_t    ident;      /* identifier for this event */
+    int16_t     filter;     /* filter for event */
+    uint16_t    flags;      /* general flags */
+    int32_t     qos;        /* quality of service */
+    uint64_t    udata;      /* opaque user data identifier */
+    uint32_t    fflags;     /* filter-specific flags */
+    uint32_t    xflags;     /* extra filter-specific flags */
+    int64_t     data;       /* filter-specific data */
+    uint64_t    ext[4];     /* filter-specific extensions */
+};
 
 #include <sys/ev.h>
 
@@ -847,14 +860,19 @@ struct ByteRangeLockPB2
 #define VKI_FSIOC_SYNC_VOLUME        _IOW('A', 1, uint32_t)
 
 
-// Libc/pthreads/pthread.c
+// libpthread/kern/workqueue_internal.h
 
-#define VKI_WQOPS_QUEUE_ADD          1
-#define VKI_WQOPS_QUEUE_REMOVE       2
-#define VKI_WQOPS_THREAD_RETURN      4
-#define VKI_WQOPS_THREAD_SETCONC     8
-#define VKI_WQOPS_QUEUE_NEWSPISUPP  16  /* check for newer SPI support */
-#define VKI_WQOPS_QUEUE_REQTHREADS  32  /* request number of threads of a prio */
+#define VKI_WQOPS_QUEUE_ADD                    1
+#define VKI_WQOPS_QUEUE_REMOVE                 2
+#define VKI_WQOPS_THREAD_RETURN                4  /* parks the thread back into the kernel */
+#define VKI_WQOPS_THREAD_SETCONC               8
+#define VKI_WQOPS_QUEUE_NEWSPISUPP            16  /* check for newer SPI support */
+#define VKI_WQOPS_QUEUE_REQTHREADS            32  /* request number of threads of a prio */
+#define VKI_WQOPS_QUEUE_REQTHREADS2           48  /* request a number of threads in a given priority bucket */
+#define VKI_WQOPS_THREAD_KEVENT_RETURN        64  /* parks the thread after delivering the passed kevent array */
+#define VKI_WQOPS_SET_EVENT_MANAGER_PRIORITY 128  /* max() in the provided priority in the the priority of the event manager */
+#define VKI_WQOPS_THREAD_WORKLOOP_RETURN     256  /* parks the thread after delivering the passed kevent array */
+#define VKI_WQOPS_SHOULD_NARROW              512  /* checks whether we should narrow our concurrency */
 
 
 #include <sys/ttycom.h>
@@ -1110,5 +1128,17 @@ struct vki_necp_aggregate_result {
 };
 #endif /* DARWIN_VERS == DARWIN_10_10 */
 
+#if DARWIN_VERS >= DARWIN_10_12
+// ulock_wake & ulock_wait operations
+#define VKI_UL_OPCODE_MASK      0x000000FF
+#define VKI_UL_FLAGS_MASK       0xFFFFFF00
+#define VKI_UL_COMPARE_AND_WAIT 1
+#define VKI_UL_UNFAIR_LOCK      2
+// ulock_wake & ulock_wait flags
+#define ULF_NO_ERRNO            0x01000000
+
+// ulock_wait flags
+#define WKI_ULF_WAIT_WORKQ_DATA_CONTENTION	0x00010000
+#endif /* DARWIN_VERS >= DARWIN_10_12 */
 
 #endif
